@@ -1,12 +1,15 @@
 import unittest
-from vector_test import Test_evector
-from matrix_test import Test_ematrix
-from module_test import Test_evspace
+from .vector_test import TestVector
+from .matrix_test import TestMatrix
+from .angles_test import TestAngles
+from .rotation_test import TestRotation
+from .refframe_test import TestReferenceFrame
 
 
 def get_suite():
 
-    testClasses = [Test_evector, Test_ematrix, Test_evspace]
+    testClasses = [TestVector, TestMatrix, TestAngles, TestRotation,
+                   TestReferenceFrame]
 
     loader = unittest.TestLoader()
 
